package cn.dg32z.lon.commands.sub;

import cn.dg32z.libs.chengzhiya.task.mhdfscheduler.scheduler.MHDFScheduler;
import cn.dg32z.libs.org.jetbrains.annotations.NotNull;
import cn.dg32z.lon.LonAntiCheat;
import cn.dg32z.lon.PluginLoader;
import cn.dg32z.lon.commands.AbstractCommand;
import cn.dg32z.lon.manager.logs.entity.Violation;
import cn.dg32z.lon.manager.logs.interfaces.ViolationManager;
import cn.dg32z.lon.utils.message.ColorUtils;
import cn.dg32z.lon.utils.time.TimeUtils;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import net.md_5.bungee.api.chat.ClickEvent;
import net.md_5.bungee.api.chat.ComponentBuilder;
import net.md_5.bungee.api.chat.HoverEvent;
import net.md_5.bungee.api.chat.TextComponent;
import org.bukkit.Bukkit;
import org.bukkit.OfflinePlayer;
import org.bukkit.command.CommandSender;
import org.bukkit.command.ConsoleCommandSender;
import org.bukkit.entity.Player;

/* loaded from: cn_dg32z_lon_commands_sub.jar:cn/dg32z/lon/commands/sub/History.class */
public final class History extends AbstractCommand {
    public History() {
        super("Show or clear player's violation history", "lonac.commands.history", false);
    }

    public void execute(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
        if (args.length < 1) {
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.history.usage"));
            return;
        }
        if (args[0].equalsIgnoreCase("clear")) {
            if (args.length == 1) {
                clearAllHistory(sender);
                return;
            }
            if (args.length == 2) {
                OfflinePlayer target = getOfflinePlayerByName(args[1]);
                if (target == null) {
                    sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.history.playernot-found"));
                    return;
                } else {
                    clearPlayerHistory(sender, target);
                    return;
                }
            }
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.history.usage"));
            return;
        }
        OfflinePlayer target2 = getOfflinePlayerByName(args[0]);
        if (target2 == null) {
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("not-found").replace("%player%", args[0]));
        } else {
            int page = args.length > 1 ? parsePage(args[1]) : 1;
            MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), dump -> {
                ViolationManager violationManager = PluginLoader.INSTANCE.getDatabaseManager().getViolationManager();
                long logCount = violationManager.getLogCount(target2);
                List<Violation> logs = violationManager.getViolations(target2, page, PluginLoader.INSTANCE.getConfigManager().getConfig().getIntElse("commands.history.pages", 10));
                long maxPages = (long) Math.ceil(((float) logCount) / 10.0f);
                sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n(target2, "commands.history.header").replace("%page%", String.valueOf(page)).replace("%maxPages%", String.valueOf(maxPages)));
                for (int i = logs.size() - 1; i >= 0; i--) {
                    Violation log = logs.get(i);
                    String hoverContent = ColorUtils.color(String.join("\n", PluginLoader.INSTANCE.getConfigManager().getConfig().getStringListElse("output.hover", List.of("&5延迟: &f%ping% &7(&fLag= &c%lagging% &7| &c%movelagging%&7)&f | &5卡顿程度: &f%tps% | &5玩家版本: &f%brand% %version%", "", "&5检查描述:", "&f%description%", "", "&5详细:", "&f%verbose%", "", "&5点击我击毙机构 &f%player% &c!"))).replace("%description%", log.getDescription()).replace("%ping%", String.valueOf(log.getPing())).replace("%lagging%", String.valueOf(log.isLagging())).replace("%movelagging%", String.valueOf(log.isMoveLagging())).replace("%tps%", String.valueOf(log.getTps())).replace("%brand%", String.valueOf(log.getBrand())).replace("%version%", String.valueOf(log.getVersion())).replace("%verbose%", log.getVerbose()).replace("%player%", (CharSequence) Objects.requireNonNull(target2.getName())));
                    TextComponent checkNameComponent = new TextComponent(ColorUtils.color(log.getCheckName()));
                    checkNameComponent.setHoverEvent(new HoverEvent(HoverEvent.Action.SHOW_TEXT, new ComponentBuilder(hoverContent).create()));
                    checkNameComponent.setClickEvent(new ClickEvent(ClickEvent.Action.RUN_COMMAND, PluginLoader.INSTANCE.getConfigManager().getConfig().getStringElse("hover-command", "/lonac spectate") + " " + target2.getName()));
                    String[] splitMessage = PluginLoader.INSTANCE.getMessageUtils().i18n("commands.history.entry").replace("%player%", args[0]).replace("%exp%", log.isExp() ? PluginLoader.INSTANCE.getMessageUtils().i18nWithOutPrefix("output.alerts.expsymbol") : "").replace("%vl%", String.valueOf(log.getVl())).replace("%timeago%", TimeUtils.formatRelativeTime(log.getCreatedAt())).replace("%server%", ColorUtils.color(log.getServer())).split("%check_name%", 2);
                    TextComponent baseMessage = new TextComponent(splitMessage[0]);
                    baseMessage.addExtra(checkNameComponent);
                    if (splitMessage.length > 1) {
                        baseMessage.addExtra(new TextComponent(splitMessage[1]));
                    }
                    if (sender instanceof Player) {
                        Player player = (Player) sender;
                        player.spigot().sendMessage(baseMessage);
                    } else if (sender instanceof ConsoleCommandSender) {
                        ConsoleCommandSender console = (ConsoleCommandSender) sender;
                        console.sendMessage(baseMessage);
                    }
                }
            });
        }
    }

    private OfflinePlayer getOfflinePlayerByName(String playerName) {
        return Bukkit.getOfflinePlayer(playerName);
    }

    private void clearAllHistory(@NotNull CommandSender sender) {
        MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), __ -> {
            ViolationManager violationManager = PluginLoader.INSTANCE.getDatabaseManager().getViolationManager();
            violationManager.clearAllLogs();
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n("commands.history.clean-all"));
        });
    }

    private void clearPlayerHistory(@NotNull CommandSender sender, OfflinePlayer target) {
        MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), __ -> {
            ViolationManager violationManager = PluginLoader.INSTANCE.getDatabaseManager().getViolationManager();
            violationManager.clearLogs(target);
            sender.sendMessage(PluginLoader.INSTANCE.getMessageUtils().i18n(target, "commands.history.clean"));
        });
    }

    private int parsePage(String pageStr) {
        try {
            return Math.max(1, Integer.parseInt(pageStr));
        } catch (NumberFormatException e) {
            return 1;
        }
    }

    public List<String> tabCompleter(@NotNull CommandSender sender, @NotNull String label, @NotNull String[] args) {
        if (args.length == 1) {
            String partialName = args[0].toLowerCase();
            List<String> list = new ArrayList<>();
            for (Player player : Bukkit.getOnlinePlayers()) {
                String name = player.getName();
                if (name.toLowerCase().startsWith(partialName)) {
                    list.add(name);
                }
            }
            return list;
        }
        if (args.length == 2 && args[1].equalsIgnoreCase("clear") && args[1].equalsIgnoreCase("clear")) {
            String partialName2 = args[1].toLowerCase();
            List<String> list2 = new ArrayList<>();
            for (Player player2 : Bukkit.getOnlinePlayers()) {
                String name2 = player2.getName();
                if (name2.toLowerCase().startsWith(partialName2)) {
                    list2.add(name2);
                }
            }
            return list2;
        }
        return List.of();
    }
}
